@@ -1,6 +1,6 @@
 package Map::Tube::London;
 
-$Map::Tube::London::VERSION   = '0.64';
+$Map::Tube::London::VERSION   = '0.65';
 $Map::Tube::London::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::London - Interface to the London Tube Map.
 
 =head1 VERSION
 
-Version 0.64
+Version 0.65
 
 =cut
 
@@ -100,8 +100,8 @@ The constructor DO NOT expects parameters.This setup the default node definition
 
 =head2 get_shortest_route($from, $to)
 
-Expects 'from' and 'to' station name and returns an object of type L<Map::Tube::Route>.
-On error it returns an object of type L<Map::Tube::Exception>.
+It expects C<$from> and C<$to> station name, required param. It returns an object
+of type L<Map::Tube::Route>. On error it throws exception of type L<Map::Tube::Exception>.
 
     use strict; use warnings;
     use Map::Tube::London;
@@ -129,7 +129,7 @@ base64 encoded string of the entire map.
     close($IMAGE);
 
 The L<London Tube Map|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/London-Tube.png>
-map as generated by plugin L<Map::Tube::Plugin::Graph>.
+as generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
@@ -189,8 +189,8 @@ L<http://search.cpan.org/dist/Map-Tube-London/>
 
 Copyright (C) 2014 - 2015 Mohammad S Anwar.
 
-This  program  is  free software; you can redistribute it and/or modify it under
-the  terms  of the the Artistic License (2.0). You may obtain a copy of the full
+This program  is free software; you can  redistribute it and / or modify it under
+the  terms  of the the Artistic License  (2.0). You may obtain a copy of the full
 license at:
 
 L<http://www.perlfoundation.org/artistic_license_2_0>
